@@ -256,7 +256,9 @@ class Module:
 
         def handler(c, u, message):
             if asyncio.iscoroutinefunction(cb):
-                asyncio.run(cb(message.topic, message.payload))
+                async def subhandler():
+                    await cb(message.topic, message.payload)
+                asyncio.run(subhandler)
             else:
                 cb(message.topic, message.payload)
 
